Enum diem_secure_storage::Identity[][src]

pub enum Identity {
    User(String),
    Anyone,
    NoOne,
}
Id represents a Diem internal identifier for a given process. For example, safety_rules or key_manager. It is up to the Storage and its deployment to translate these identifiers into verifiable material. For example, the process running safety_rules may have a token that is intended for only safety_rules to own. The specifics are left to the implementation of the storage backend interface layer.

Variants

User(String)

Tuple Fields of User

0: String
Anyone
NoOne