Enum diem_secure_storage::Storage [−][src]
pub enum Storage {
GitHubStorage(GitHubStorage),
VaultStorage(VaultStorage),
InMemoryStorage(InMemoryStorage),
NamespacedStorage(Namespaced<Box<Storage>>),
OnDiskStorage(OnDiskStorage),
}Expand description
This is the Diem interface into secure storage. Any storage engine implementing this trait should support both key/value operations (e.g., get, set and create) and cryptographic key operations (e.g., generate_key, sign and rotate_key). This is a hack that allows us to convert from SecureBackend into a useable T: Storage. This boilerplate can be 100% generated by a proc macro.
Variants
GitHubStorage(GitHubStorage)Tuple Fields of GitHubStorage
VaultStorage(VaultStorage)Tuple Fields of VaultStorage
0: VaultStorageInMemoryStorage(InMemoryStorage)Tuple Fields of InMemoryStorage
NamespacedStorage(Namespaced<Box<Storage>>)Tuple Fields of NamespacedStorage
0: Namespaced<Box<Storage>>OnDiskStorage(OnDiskStorage)Tuple Fields of OnDiskStorage