Struct diem_secure_storage::GetResponse [−][src]
pub struct GetResponse<T> {
pub last_update: u64,
pub value: T,
}Expand description
A container for a get response that contains relevant metadata and the value stored at the given key.
Fields
last_update: u64Time since Unix Epoch in seconds.
value: TValue stored at the provided key
Implementations