Struct diem_secure_storage::Namespaced [−][src]
pub struct Namespaced<S> { /* fields omitted */ }Expand description
This provides a light wrapper around KV storages to support a namespace. That namespace is effectively prefixing all keys with then namespace value and “/” so a namespace of foo and a key of bar becomes “foo/bar”. Without a namespace, the key would just be “bar”.
Implementations
This is a small hack in order to allow for calling KVStorage::get from a Namespaced created
from an &S and not an S