Struct diem_secure_storage::GitHubStorage [−][src]
pub struct GitHubStorage { /* fields omitted */ }Expand description
GitHubStorage leverages a GitHub repository to provide a file system approach to key / value storage. This is not intended for storing private data but for organizing public data.
Implementations